/**
 * @typedef fsdkErrorType
 *
 */
export declare const fsdkErrorTypes: {
    /** Errors stemming from the database */
    DB_ERROR: string;
    DUPLICATE_ERROR: string;
    INVALID_ARGUMENT: string;
    INVALID_DATA: string;
    NOT_FOUND: string;
    NOT_ALLOWED: string;
    UNEXPECTED_STATE: string;
    CONFLICT: string;
    FORBIDDEN: string;
    UNAUTHORIZED: string;
    TOO_MANY_REQUESTS: string;
};
export declare const fsdkErrorCodes: {
    INSUFFICIENT_INVENTORY: string;
    CART_INCOMPATIBLE_STATE: string;
};
/**
 * Standardized error to be used across fsdk project.
 * @extends Error
 */
declare class fsdkError extends Error {
    type: string;
    message: string;
    code?: string;
    date: Date;
    static Types: {
        /** Errors stemming from the database */
        DB_ERROR: string;
        DUPLICATE_ERROR: string;
        INVALID_ARGUMENT: string;
        INVALID_DATA: string;
        NOT_FOUND: string;
        NOT_ALLOWED: string;
        UNEXPECTED_STATE: string;
        CONFLICT: string;
        FORBIDDEN: string;
        UNAUTHORIZED: string;
        TOO_MANY_REQUESTS: string;
    };
    static Codes: {
        INSUFFICIENT_INVENTORY: string;
        CART_INCOMPATIBLE_STATE: string;
    };
    /**
     * Creates a standardized error to be used across fsdk project.
     * @param {string} type - type of error
     * @param {string} message - message to go along with error
     * @param {string} code - code of error
     * @param {Array} params - params
     */
    constructor(type: string, message: string, code?: string, ...params: any);
}
export default fsdkError;
